import random
import string
import sys

def start():
    length = 12
    if len(sys.argv) > 1:
        try:
            length = int(sys.argv[1])
        except ValueError:
            pass

    chars = string.ascii_letters + string.digits + string.punctuation
    password = ''.join(random.choice(chars) for _ in range(length))
    
    print(f"Generated password: {password}")

if __name__ == "__main__":
    start()


from setuptools import setup, find_packages

setup(
    name="tole-tool",
    version="1.0.1beta",
    packages=find_packages(),
    install_requires=[
        "pyinstaller",
    ],
    entry_points={
        'console_scripts': [
            'tole=tole.tole_cli:start',
        ],
    },
    author="Your Name",
    description="CLI tool to convert Python to EXE",
    python_requires='>=3.6',
)